==> igniteui-angular-core-17.3.0.tgz: package/esm2015/lib/OpenStreetMapImageryDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { GeographicMapImageryDescriptionMetadata } from "./GeographicMapImageryDescriptionMetadata";
import { OpenStreetMapImageryDescription } from "./OpenStreetMapImageryDescription";
/**
 * @hidden
 */
export let OpenStreetMapImageryDescriptionMetadata = /*@__PURE__*/ (() => {
    class OpenStreetMapImageryDescriptionMetadata extends Base {
        static b(a) {
            if (OpenStreetMapImageryDescriptionMetadata.a == null) {
                OpenStreetMapImageryDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                OpenStreetMapImageryDescriptionMetadata.c(OpenStreetMapImageryDescriptionMetadata.a);
            }
            if (a.k(OpenStreetMapImageryDescriptionMetadata.a)) {
                return;
            }
            a.ab(OpenStreetMapImageryDescriptionMetadata.a);
        }
        static c(a) {
            GeographicMapImageryDescriptionMetadata.c(a);
            a.item("TilePath", "String");
        }
        static d(a) {
            OpenStreetMapImageryDescriptionMetadata.b(a);
            a.ad("OpenStreetMapImagery", () => new OpenStreetMapImageryDescription());
            a.ac("OpenStreetMapImagery", OpenStreetMapImageryDescriptionMetadata.a);
        }
    }
    OpenStreetMapImageryDescriptionMetadata.$t = markType(OpenStreetMapImageryDescriptionMetadata, 'OpenStreetMapImageryDescriptionMetadata');
    OpenStreetMapImageryDescriptionMetadata.a = null;
    return OpenStreetMapImageryDescriptionMetadata;
})();

==> igniteui-angular-core-20.0.0.tgz: package/esm2015/lib/OpenStreetMapImageryDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { GeographicMapImageryDescriptionMetadata } from "./GeographicMapImageryDescriptionMetadata";
import { OpenStreetMapImageryDescription } from "./OpenStreetMapImageryDescription";
/**
 * @hidden
 */
export let OpenStreetMapImageryDescriptionMetadata = /*@__PURE__*/ (() => {
    class OpenStreetMapImageryDescriptionMetadata extends Base {
        static b(a) {
            if (OpenStreetMapImageryDescriptionMetadata.a == null) {
                OpenStreetMapImageryDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                OpenStreetMapImageryDescriptionMetadata.c(OpenStreetMapImageryDescriptionMetadata.a);
            }
            if (a.k(OpenStreetMapImageryDescriptionMetadata.a)) {
                return;
            }
            a.ac(OpenStreetMapImageryDescriptionMetadata.a);
        }
        static c(a) {
            GeographicMapImageryDescriptionMetadata.c(a);
            a.item("TilePath", "String");
        }
        static d(a) {
            OpenStreetMapImageryDescriptionMetadata.b(a);
            a.ae("OpenStreetMapImagery", () => new OpenStreetMapImageryDescription());
            a.ad("OpenStreetMapImagery", OpenStreetMapImageryDescriptionMetadata.a);
        }
    }
    OpenStreetMapImageryDescriptionMetadata.$t = markType(OpenStreetMapImageryDescriptionMetadata, 'OpenStreetMapImageryDescriptionMetadata');
    OpenStreetMapImageryDescriptionMetadata.a = null;
    return OpenStreetMapImageryDescriptionMetadata;
})();
